@@ -39,7 +39,7 @@ if test "$ARCHITECTURE" = i386; then
 	esac
 fi
 case "$RELEASE" in
-	jessie|stretch)
+	jessie|stretch|buster)
 		MIRROR=http://archive.debian.org/debian
 	;;
 esac
