@@ -1,5 +1,7 @@
 #!/bin/sh
-# Copyright 2023 Johannes Schauer Marin Rodrigues <josch@debian.org>
+# SPDX-FileCopyrightText: 2023 Johannes Schauer Marin Rodrigues <josch@debian.org>
+# SPDX-FileCopyrightText: 2024-2025 Helmut Grohne <helmut@subdivi.de>
+# SPDX-FileCopyrightText: 2025 Jochen Sprickerhof <debvm@jochen.sprickerhof.de>
 # SPDX-License-Identifier: MIT
 #
 # Add a non-root user, add them to the sudo group and use the same authorized
@@ -7,7 +9,8 @@
 #
 #  - the new user is called "user" by default (customizable via $USERADDHOOK_USERNAME)
 #  - no password required for login
-#  - requires the passwd and coreutils packages installed inside the chroot
+#  - requires the coreutils package installed inside the chroot
+#  - requires the passwd package installed outside the chroot
 #  - adds the new user to the sudo group if it exists
 #  - ~/.ssh/authorized_keys files is copied from root user if it exists
 #  - enables immediate autologin via lightdm if installed
@@ -26,11 +29,22 @@ set -eu
 
 : "${USERADDHOOK_USERNAME:=user}"
 
-chroot "$1" useradd --home-dir "/home/$USERADDHOOK_USERNAME" --create-home --shell /bin/bash "$USERADDHOOK_USERNAME"
-chroot "$1" passwd --delete "$USERADDHOOK_USERNAME"
+useradd --prefix "$1" --no-log-init --home-dir "/home/$USERADDHOOK_USERNAME" --create-home --shell /bin/bash "$USERADDHOOK_USERNAME"
+
+if passwd --help | grep -q -e --prefix; then
+	passwd --prefix "$1" --delete "$USERADDHOOK_USERNAME"
+else
+	# Host OS is older than trixie
+	PWFILE=passwd
+	if grep -q "^$USERADDHOOK_USERNAME:x:" "$1/etc/passwd"; then
+		PWFILE=shadow
+	fi
+	sed -i -e "s/^\\($USERADDHOOK_USERNAME:\\)[^:]*:/\\1:/" "$1/etc/$PWFILE"
+fi
+
 if chroot "$1" getent group sudo >/dev/null; then
 	echo "Adding $USERADDHOOK_USERNAME to sudo group"
-	chroot "$1" usermod --append --groups sudo "$USERADDHOOK_USERNAME"
+	usermod --prefix "$1" --append --groups sudo "$USERADDHOOK_USERNAME"
 fi
 if [ -e "$1"/root/.ssh/authorized_keys ]; then
 	echo "Installing ssh authorized_keys for $USERADDHOOK_USERNAME"
